package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0,```````````(``P`!````P)D$"#0```"<KP```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(I*L`
M`*2K```%`````!````$```"DJP``I#L%"*0[!0B$`@``[!(```8`````$```
M`@```+BK``"X.P4(N#L%"!`!```0`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&2PI0``L"4%"+`E!0CL````[`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`,3OF9'@L']"7G`"'P:]6HP?BK:Z)0```$\````(
M````"``````0$`0E0`2`J!$``:*&0:A````"2R@$*3BB,D>*!`R(3P```%$`
M``````````````````!4````5@```%<`````````6````%D`````````6@``
M`%L```!<`````````%T```````````````````!>````80``````````````
M8@```&0```!E````9P````````!I````;`````````!N````;P```'````!Q
M`````````,C5LG%9Z.WLYO\PHL[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?Y
MG(%K"4/6#3J7"\6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8
M'+OCDGS49-1\K4OCP#)BV^WAIP(*9J_,9F`6R5E[\$IKXD?&`4-%U>Q'[#,Z
M?4&.Q</E/RSRV],=^J%L8+F-\0X`````````````````````*0,`````````
M````$@```*P``````````````!(```"^`P`````````````2````J0,`````
M````````$@```)P!`````````````!(```#N`P`````````````2````=0(`
M````````````$@````P``````````````"`````;```````````````@````
MKP,`````````````$@```(@!`````````````!(````/!``````````````2
M````:0$`````````````$@```'L!`````````````!(```!@`P``````````
M```2````.@,`````````````$@```"<"`````````````!(```#X````````
M```````2````%P(`````````````$@```-,#`````````````!(```#%`0``
M```````````2````>00`````````````$@```#X$`````````````!(````(
M`P`````````````2````0@,`````````````$@```),"`````````````!(`
M``#E`0`````````````2````H0$`````````````$@```#`"````````````
M`!(```#\`P`````````````2````:P0`````````````$@```"H!````````
M`````!(````'!``````````````2````+P``````````````$@```!D$````
M`````````!(```!8`0`````````````2````PP``````````````$@```$L$
M`````````````!(```#G`P`````````````2````-P0`````````````$@``
M`,P#`````````````!(```"B`P`````````````2````3@4`````````````
M$@```#P!`````````````!(````G!``````````````2````5P(`````````
M````$@```(@#`````````````!(````<`P`````````````2````20(`````
M````````$@```-H#`````````````!(```",`@`````````````2````I@$`
M````````````$@```)$#`````````````!(```#A`P`````````````2````
MQ0,`````````````$@```.<``````````````!(````]```````````````2
M````+@0`````````````$@```&,$`````````````!(```#2````````````
M```2````^0$`````````````$@```(`"`````````````!(```!+`0``````
M```````2````500`````````````$@```+<#`````````````!(```!W`P``
M```````````2````(@,`````````````$@```!@!`````````````!(````^
M`@`````````````2````3P``````````````$@```-,!`````````````!(`
M``!>```````````````2````<@0`````````````$@```(H`````````````
M`!(```!_`P`````````````2````<@,`````````````$@```',`````````
M`````!(````&`0`````````````2````L@$``#"5!`@`````$@```.\$``"@
MR00(!````!$`#P"X!0``0,P$"&Y9```1``\`P@4``&"Z!`CB"```$@`-`.X%
M``#@L@0(=0$``!(`#0#I!```;,D$"``````2``X`C00``$`^!0@$````(0`9
M`,$$``"PKP0(#0```!(`#0"'!0``X,@$"%H````2``T`FP````"7!`@`````
M$@```'(%```8/@4(`````!``&`!T!0``&#X%"``````@`!@`C`0``$`^!0@$
M````(0`9`-\$``#0R`0(!0```!(`#0#A!0``,+@$""@"```2``T`#`4``$"H
M!`A$````$@`-`(L$``!`/@4(!````!$`&0"&!```$+8$""`"```2``T`/`4`
M`&"T!`@@````$@`-`%<%``"0M00(?@```!(`#0"<!```*#X%"``````0`/'_
MJ`0``)!.!0@`````$`#Q__8$``!0PP0(C`0``!(`#0!1`P``I,D$"`0````1
M``\`>`4``,"9!`@`````$@`-`!H%``#@K@0(Q````!(`#0`P!0``@+0$"!`!
M```2``T`8P4``"0^!0@$````$0`8`&4"``#PE@0(`````!(```#2!```@)H$
M"#,````2``T`E00``"@^!0@`````$`#Q_[,%```@/@4(!````!$`&`"7!0``
MT*D$"%T````2``T`?P4``.#'!`@_````$@`-`)X"``!$/@4($P```!$`&0#/
M!0``L+$$""@!```2``T`@04``("4!`@`````$@`+``!L:6)P97)L+G-O`%]?
M9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R
M;0!097)L7TES=&%T8G5F7W!T<@!097)L7W-Y<U]I;FET,P!097)L7TEE>&ET
M7V9L86=S7W!T<@!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?26-O;7!C
M=E]P='(`4&5R;%]A=&9O<FM?;&]C:P!097)L7TEC=7)S=&%C:VEN9F]?<'1R
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!A
M<G-E<E]P='(`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L
M7TET;W!?96YV7W!T<@!097)L7TET86EN=&5D7W!T<@!097)L7W-V7W-E='!V
M;@!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!097)L7TEI;E]E=F%L
M7W!T<@!097)L7TEO<%]P='(`4&5R;%])979A;%]R;V]T7W!T<@!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]'=&AR7VME>5]P='(`4&5R;%]'9&]?=6YD=6UP7W!T<@!097)L
M7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)R
M97-O;'8N<V\N,@!L:6)N<VPN<V\N,0!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L
M:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)P=&AR96%D+G-O+C``<'1H
M<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO
M;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G
M:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G
M971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y
M7V-H:P!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`"]U<W(O;&EB+W!E<FPU+T-/4D4`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``<VEZ95]L;V%D7VUE7S(`7U]D871A7W-T87)T`'AS
M7VEN:70`7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)3
M5$%#2P!N86UE7VQO861?;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)
M0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C,N-`!'3$E"
M0U\R+C```````@````,``P````0``````````P````4```````8`!P``````
M```#`````P`$``(``@```````P````4``P````,````(```````%``,``P`#
M``,``P````,````#``(````#``,````)``,``P```````P`#````````````
M!``#``,`!P```````````````P````,``P`````````!``$``0`!``$``P`!
M``$````!``$``P`!``$``0`#``$``0`!``$``0`!``$``0`!``$``0````$`
M`0`!``$``0````$``0`!``8`1P,``!````!P````%&EI#0``"0#[!0``$```
M`!-I:0T```@`!08``!````!R&6D)```&``\&```0````$FEI#0``!0`;!@``
M$````'09:0D```0`)08``!`````0:6D-```#`#$&`````````0`"`/@"```0
M`````````!)I:0T```<`&P8``!`````0:6D-```"`#$&````````R#P%"`8(
M``!`/@4(!5\``$0^!0@%<0``V#P%"`<!``#</`4(!P(``.`\!0@'`P``Y#P%
M"`<$``#H/`4(!P4``.P\!0@'!@``\#P%"`<'``#T/`4(!T\``/@\!0@'"```
M_#P%"`<*````/04(!PL```0]!0@'#```"#T%"`<-```,/04(!PX``!`]!0@'
M#P``%#T%"`<0```8/04(!Q$``!P]!0@'$@``(#T%"`<3```D/04(!Q0``"@]
M!0@'%0``+#T%"`<6```P/04(!Q<``#0]!0@'&```.#T%"`<9```\/04(!QH`
M`$`]!0@'&P``1#T%"`<<``!(/04(!QT``$P]!0@''@``4#T%"`<?``!4/04(
M!R```%@]!0@'(0``7#T%"`<B``!@/04(!R,``&0]!0@':P``:#T%"`=8``!L
M/04(!R0``'`]!0@')0``=#T%"`<F``!X/04(!R<``'P]!0@'*```@#T%"`<I
M``"$/04(!RH``(@]!0@'*P``C#T%"`<L``"0/04(!RT``)0]!0@'+@``F#T%
M"`<O``"</04(!S```*`]!0@',0``I#T%"`<R``"H/04(!S,``*P]!0@'-```
ML#T%"`<U``"T/04(!S8``+@]!0@'-P``O#T%"`<X``#`/04(!SD``,0]!0@'
M.@``R#T%"`<[``#,/04(!SP``-`]!0@'/0``U#T%"`<^``#8/04(!S\``-P]
M!0@'0```X#T%"`=!``#D/04(!T(``.@]!0@'0P``[#T%"`=$``#P/04(!T4`
M`/0]!0@'1@``^#T%"`='``#\/04(!T@````^!0@'20``!#X%"`=*```(/@4(
M!TL```P^!0@'3```$#X%"`=-```4/@4(!TX``%6)Y5.#[`3H`````%N!PT"H
M``"+D_S___^%TG0%Z)X```#HJ04``.B4-```6%O)P_\UT#P%"/\EU#P%"```
M``#_)=@\!0AH`````.G@_____R7</`4(:`@```#IT/____\EX#P%"&@0````
MZ<#_____)>0\!0AH&````.FP_____R7H/`4(:"````#IH/____\E[#P%"&@H
M````Z9#_____)?`\!0AH,````.F`_____R7T/`4(:#@```#I</____\E^#P%
M"&A`````Z6#_____)?P\!0AH2````.E0_____R4`/04(:%````#I0/____\E
M!#T%"&A8````Z3#_____)0@]!0AH8````.D@_____R4,/04(:&@```#I$/__
M__\E$#T%"&AP````Z0#_____)10]!0AH>````.GP_O___R48/04(:(````#I
MX/[___\E'#T%"&B(````Z=#^____)2`]!0AHD````.G`_O___R4D/04(:)@`
M``#IL/[___\E*#T%"&B@````Z:#^____)2P]!0AHJ````.F0_O___R4P/04(
M:+````#I@/[___\E-#T%"&BX````Z7#^____)3@]!0AHP````.E@_O___R4\
M/04(:,@```#I4/[___\E0#T%"&C0````Z4#^____)40]!0AHV````.DP_O__
M_R5(/04(:.````#I(/[___\E3#T%"&CH````Z1#^____)5`]!0AH\````.D`
M_O___R54/04(:/@```#I\/W___\E6#T%"&@``0``Z>#]____)5P]!0AH"`$`
M`.G0_?___R5@/04(:!`!``#IP/W___\E9#T%"&@8`0``Z;#]____)6@]!0AH
M(`$``.F@_?___R5L/04(:"@!``#ID/W___\E<#T%"&@P`0``Z8#]____)70]
M!0AH.`$``.EP_?___R5X/04(:$`!``#I8/W___\E?#T%"&A(`0``Z5#]____
M)8`]!0AH4`$``.E`_?___R6$/04(:%@!``#I,/W___\EB#T%"&A@`0``Z2#]
M____)8P]!0AH:`$``.D0_?___R60/04(:'`!``#I`/W___\EE#T%"&AX`0``
MZ?#\____)9@]!0AH@`$``.G@_/___R6</04(:(@!``#IT/S___\EH#T%"&B0
M`0``Z<#\____):0]!0AHF`$``.FP_/___R6H/04(:*`!``#IH/S___\EK#T%
M"&BH`0``Z9#\____);`]!0AHL`$``.F`_/___R6T/04(:+@!``#I</S___\E
MN#T%"&C``0``Z6#\____);P]!0AHR`$``.E0_/___R7`/04(:-`!``#I0/S_
M__\EQ#T%"&C8`0``Z3#\____)<@]!0AHX`$``.D@_/___R7,/04(:.@!``#I
M$/S___\ET#T%"&CP`0``Z0#\____)=0]!0AH^`$``.GP^____R78/04(:``"
M``#IX/O___\EW#T%"&@(`@``Z=#[____)>`]!0AH$`(``.G`^____R7D/04(
M:!@"``#IL/O___\EZ#T%"&@@`@``Z:#[____)>P]!0AH*`(``.F0^____R7P
M/04(:#`"``#I@/O___\E]#T%"&@X`@``Z7#[____)?@]!0AH0`(``.E@^___
M_R7\/04(:$@"``#I4/O___\E`#X%"&A0`@``Z4#[____)00^!0AH6`(``.DP
M^____R4(/@4(:&`"``#I(/O___\E##X%"&AH`@``Z1#[____)1`^!0AH<`(`
M`.D`^____R44/@4(:'@"``#I\/K__S'M7HGA@^3P4%12:-#(!`AHX,@$"%%6
M:!"V!`CH+_S___20D)"0D)"0D)"0D)"0D%6)Y5.-9"3\@#U8/@4(`'4^N[`[
M!0BA7#X%"('KK#L%",'[`H/K`3G8<QV0C70F`(/``:-</@4(_Q2%K#L%"*%<
M/@4(.=ARZ,8%6#X%"`&-9"0$6UW#C78`C;PG`````%6)Y8UD).BAM#L%"(7`
M=!*X`````(7`=`G'!"2T.P4(_]#)PY"0D)"0D)"0D)"0D%6)Y593BW4(B?`/
MM@Z$R70>H9#+!`B-5@$/MAB)\&:0.-D/M@H/1,*$R8U2`77Q6UY=PXVV````
M`(V\)P````!5,=*)Y5>)QU:#QQR-M;3^__]3C:0DL/[__XF%K/[__XL,EXG(
MB<O!XQC!Z!@)V(G+P>,(@>,``/\`P>D("=B!X0#_```)R(D$EHU2`8/Z$'7.
MC97H_O__C4WHD(UT)@"+0NPS`C-"U#-"S,'('XE"#(U2!#G*=>B+E:S^__^+
MA:S^__^)T8L`B86H_O__BT$0BXVH_O__`X6T_O__P<D;BW($BWH(BU(,B?LA
M\XV,")EY@EJ)\/?0(=`#E;C^__\)V(N=J/[__P'!BX6H_O__P<X"]]`A\R'X
M"=@#O;S^__^+G:C^___!RP*-E`*9>8):B<C!R!L!PHG0P<@;C80'F7F"6HF%
MI/[__XG(B<_WT"'?(?`#M<#^__\)^`.%I/[__XFUI/[__XG6P<D"B=?WUB'/
M(=X#G<3^__\)_HN]I/[__\'*`HVT-YEY@EJ)M;#^__^)QL'.&P.UL/[__XGW
MP<\;C;P[F7F"6HG#B;VD_O__]].)QR'+(=<)^P.=I/[__P.-R/[__XGWB8VD
M_O__B?'!R`+WT2''(=$)^8N]I/[__P.5S/[__\'.`HV,#YEY@EJ)C;#^__^)
MV<')&P.-L/[__XG/P<\;C;PZF7F"6HG:B;VD_O__]]*)WR'"(?<#A=#^__\)
M^@.5I/[__XF%I/[__XG(P<L"B<_WT"'?(?`#M=3^__\)^(N]I/[__\')`HV$
M!YEY@EJ)A;#^__^)T(N]L/[__\'(&P''B?C!R!N-A`:9>8):B86D_O__B=")
MUO?0(<XAV`.=V/[__PGP`X6D_O__B9VD_O__B?O!R@*)_O?3(=8ARPGSB[6D
M_O__`XW<_O__P<\"C9P>F7F"6HF=L/[__XG#P<L;`YVP_O__B=[!SAN-M#&9
M>8):B<&)M:3^___WT8G&(=$A_@.5X/[__PGQ`XVD_O__B96D_O__B=K!R`*)
MWO?2(<8A^@.]Y/[__PGRB[6D_O__P<L"C906F7F"6HF5L/[__XG*B[6P_O__
MP<H;`=:)\L'*&XV4%YEY@EJ)E:3^__^)RHG/]](AWR'"`X7H_O__"?H#E:3^
M__^)A:3^__^)\,')`HGW]]`ASR'8`YWL_O__"?B+O:3^___!S@*-A`>9>8):
MB86P_O__B="+O;#^___!R!L!QXGXP<@;C80#F7F"6HF%I/[__XG0B=/WT"'S
M(<@#C?#^__\)V`.%I/[__XF-I/[__XGYP<H"B?OWT2'3(?$)V8N=I/[__\'/
M`HV,"YEY@EJ)C;#^__^)P8N=L/[__\')&P.U]/[__P'+B=G!R1N-C`Z9>8):
MB8VD_O__B<&)QO?1(?XAT0.5^/[__PGQ`XVD_O__B96D_O__B=K!R`*)WO?2
M(<8A^@.]_/[__PGRB[6D_O__P<L"C906F7F"6HF5L/[__XG*B[6P_O__P<H;
M`=:)\L'*&XV4%YEY@EJ)E:3^__^)RHG/]](AWR'""?H#E:3^___!R0(#A0#_
M__^)A:3^__^)\(GW]]`ASR'8"?B+O:3^___!S@(#G03___^-A`>9>8):B?<Q
MSXF%L/[__S'7B=#!R!L#A;#^___!R@(#C0C___^-O#NAZ]ENB</!RQL!^XG7
M,?<#M0S___\QQ\'(`HV\.:'KV6Z)V<')&P'YB<<QUP.5$/___S'?P<L"C;P^
MH>O9;HG.P<X;`?Z)WS''`X44____,<_!R0*-O#JAZ]ENB?+!RAL!^HG/,=\#
MG1C___\Q]\'.`HV\.*'KV6Z)T,'(&P''B?`QR`.-'/___S'0P<H"C9P#H>O9
M;HGXP<@;`=B)TS'S`[4@____,?O!SP*-G!FAZ]ENB<'!R1L!RXGY,=$#E23_
M__\QP<'(`HVT#J'KV6Z)V<')&P'QB<8Q_@.]*/___S'>P<L"C;0RH>O9;HG*
MP<H;`=:)VC'",<J-O!>AZ]ENB?+!RAL!^@.%+/___\')`HG/,=\#G3#___\Q
M]\'.`HV\.*'KV6Z)T,'(&P''B?`QR`.--/___S'0P<H"C9P#H>O9;HGXP<@;
M`=B)TS'S`[4X____,?O!SP*-G!FAZ]ENB<'!R1L!RXGY,=$#E3S___\QP<'(
M`HVT#J'KV6Z)V<')&P'QB<8Q_@.]0/___S'>P<L"C;0RH>O9;HG*P<H;`=:)
MVC'"`X5$____,<K!R0*-O!>AZ]ENB?+!RAL!^HG/,=\#G4C___\Q]\'.`HV\
M.*'KV6Z)T,'(&P''B?`QR`.-3/___S'0P<H"C9P#H>O9;HGXP<@;`=B)TS'S
M`[50____,?O!SP*-G!FAZ]ENB<'!R1L!V8G[,=,#E53___\QPXF5I/[__\'(
M`HG"(?J-M!ZAZ]ENB<O!RQL!\XG&"?XAS@G6BY6D_O__P<D"`[U8____B;VD
M_O__B<\AQXVT,MR\&X^)VL'*&P'RB<X)Q@.%7/___R'>"?Z+O:3^___!RP*)
MA:3^__^)V"'(C;0WW+P;CXG?"<^)M;#^__\AUXG6"<>+A:3^___!SAL#M;#^
M___!R@(#C6#___^)C:3^__^)T8V\.-R\&X^)\,'(&R'9`?B)UPG?`YUD____
M(?<)SXN-I/[__\'.`HF=I/[__XGS(=.-O#G<O!N/B<'!R1L!^8GW"=<AQPG?
MBYVD_O__C;P[W+P;CXG+P<L;`Y5H____P<@"`?N)QXF5I/[__PGWB<(A\B'/
M"=>+E:3^___!R0(#M6S___^)M:3^__^)SB'&C;PZW+P;CXG:P<H;`?J)SPG'
M`X5P____(=\)]XNUI/[__\'+`HF%I/[__XG8(<B-O#[<O!N/B=;!SAL!_HG?
M"<\#C73___\AUPG'BX6D_O__P<H"B8VD_O__B=$AV8V\.-R\&X^)\,'(&P'X
MB=<)WR'W"<^+C:3^__^-O#G<O!N/B<'!R1L!^0.=>/___\'.`HF=I/[__XGW
MB?,)UR'3(<<#E7S___\)WXN=I/[__\'(`HF5I/[__XG"(?*-O#O<O!N/B<O!
MRQL!^XG'"?<#=8`ASPG7BY6D_O__P<D"B;6D_O__B<XAQHV\.MR\&X^)VL'*
M&P'ZB<\)QP-%A"'?"?>+M:3^___!RP*)A:3^__^)V"'(C;P^W+P;CXG6P<X;
M`?Z)WPG/(=<)QXN%I/[__XV\.-R\&X^)\,'(&P'XP<H"`TV(B=>)C:3^__\)
MWXG1(=DA]PG/BXVD_O__P<X"`UV,B9VD_O__B?,ATXV\.=R\&X^)P<')&P'Y
MB?<)UP-5D"''"=^+G:3^___!R`*)E:3^__^)PB'RC;P[W+P;CXG+P<L;`?N)
MQPGW`W64(<\)UXN5I/[__\')`HFUI/[__XG.(<:-O#K<O!N/B=K!RAL!^HG/
M"<<AWPGWB[6D_O__P<L"C;P^W+P;CXG6P<X;`?X#19B)WXF%I/[__PG/B=@A
MR"'7"<>+A:3^___!R@(#39R)C:3^__^)T2'9C;PXW+P;CXGPP<@;`?B)UPG?
M`UV@(?<)SXN-I/[__\'.`HF=I/[__XGS(=.-O#G<O!N/B<'!R1L!SXGQ"=$#
M5:0AP0G9BYVD_O__P<@"C8P+W+P;CXG#,?.)C;#^__\Q^XGYP<D;`XVP_O__
MP<\"`W6HC9P:UL%BRHG*P<H;`=.)^C'",<J-M!;6P6+*B=K!RAL#1:S!R0(!
M\HG.,?X#?;`QWL'+`HVT,-;!8LJ)T,'(&P'&B=@QR`--M#'0P<H"C;P'UL%B
MRHGPP<@;`?B)US'?`UVX,??!S@*-O#G6P6+*B<'!R1L!SXGQ,=$#5;PQP<'(
M`HV<"];!8LJ)^<')&P'9B<,Q\S'[P<\"C9P:UL%BRHG*P<H;`=.)^@-UP#'"
M,<H#1<3!R0*-M!;6P6+*B=K!RAL!\HG.,?X#?<@QWL'+`HVT,-;!8LJ)T,'(
M&P'&B=@QR`--S#'0P<H"C;P'UL%BRHGPP<@;`?B)US'?`UW0,??!S@*-O#G6
MP6+*B<'!R1L!SXGQ,=$#5=0QP<'(`HV<"];!8LJ)^<')&P'9B<,Q\S'[C9P:
MUL%BRHG*P<H;`W78P<\"`=.)^C'"`T7<,<K!R0*-M!;6P6+*B=K!RAL!\HG.
M,?X#?>`QWL'+`HVT,-;!8LJ)T,'(&P'&B=@QR`--Y#'0P<H"C;P'UL%BRHGP
MP<@;`?B)US'?`UWH,??!S@*-O#G6P6+*B<'!R1L!^8GW,=<QQ\'(`HV\.];!
M8LJ)R\'+&P'[B<<#5>PQ]S'/P<D"C;PZUL%BRHG:P<H;`=>+E:C^__\#5?"-
MM!;6P6+*B<HQPC':`?*)_L'.&P'RB[6L_O__P<L"B18!?@0!7@@!3@P!1A"-
MI"10`0``6UY?7<.0C70F`%6)Y8UD),B%P(E=](EU^(E]_(G#B57<=0\QP(M=
M](MU^(M]_(GL7<.A0#X%"(7`B47@=.4/M@,\/715A,")VG1/C5(!#[8"/#UT
M!(3`=?(IVHM%X(LPA?9TOXE=Y(G'B=.-M"8`````BT7DB5PD"(E$)`2)-"3H
M!?'__X7`=0:`/!X]=!.-?P2+-X7V==KKB3'2Z[V-="8`BT7<*WW@P?\"B3B-
M1!X!Z6____^-="8`58GEC60DZ(U5].A!____R</K#9"0D)"0D)"0D)"0D)!5
MB>6-9"3XH1P^!0B#^/]T!\G#D(UT)@"XK,D$".B^____A<!T&@^V`(3`=!,\
M,`^5P`^VP*,</@4(R<.-="8`,<#K\8VV`````(V_`````%6)Y5:)QE.-7?2-
M9"3PZQB+1?3!X`(#!4`^!0B-0`2+$(72B5#\=?2)VHGPZ*_^__^%P'7;C60D
M$%M>7<.-=@!5B>6-I"2X[___QT0D"/\/``#'!"2VR00(9:$4````B47D,<")
M7?2)=?B)??R)TXF-U.___XV]Y.___XE\)`3H7.___X7`B<9^=HU`_X"\!>3O
M__\`=&&)="0(QT0D!"\```")/"3HI>___X7`=%''!"0`````Z/7O__^+`(D$
M).C;[/__B00DB70D#(E\)`B)7"0$Z"?N__^+1>1E,P44````=4F+7?2+=?B+
M??R)[%W#C;8`````A<!T!(G&ZY?'!"0`````Z*3O__^+`(D$).B*[/__BY74
M[___B5PD!(E4)`B)!"3H1.S__^NKZ%WN__^-M@````"-O"<`````58GEC60D
MZ,<$)`````#H7>___XL`B00DZ$/L__^)!"3'1"0$_____^B#[/__QP0D````
M`.@W[___BP")!"3H'>S__XD$),=$)`@`````QT0D!#"J!`CH=>___\G#C78`
M58GE4XUD).S'!"0`````Z/SN__^+`(D$).CBZ___B00DZ'KJ__^+`(M8!,<$
M)`````#HV>[__XL`B00DZ+_K__^)!"3H!^O__P^V`(A#&,<$)`````#HM>[_
M_XL`B00DZ)OK__^)!"3H,^K__XL`BU@$QP0D`````.B2[O__BP")!"3H>.O_
M_XD$).C0ZO__BP`/MT`09B7_`6:)0QK'!"0`````Z&;N__^+`(D$).A,Z___
MB00DZ.3I__^+`(M8!,<$)`````#H0^[__XL`B00DZ"GK__^)!"3'1"0(````
M`,=$)`0ERP0(Z*'M__^)0QS'!"0`````Z!+N__^+`(D$).CXZO__B00DZ)#I
M__^+`(M8!,<$)`````#H[^W__XL`B00DZ-7J__^)!"3H_>G__XL`B4,@QP0D
M`````.C,[?__BP")!"3HLNK__XD$).A*Z?__BP"+6`3'!"0`````Z*GM__^+
M`(D$).B/ZO__B00DZ*?L__^+`#'2A<!T(\<$)`````#H@^W__XL`B00DZ&GJ
M__^)!"3H@>S__XL`BU!LB5,DQP0D`````.A=[?__BP")!"3H0^K__XD$).C;
MZ/__BP"+0`3'0"@`````QP0D`````.@S[?__BP")!"3H&>K__XD$).BQZ/__
MBP"+0`3'0"P`````QP0D`````.@)[?__BP")!"3H[^G__XD$).B'Z/__BP"+
M6`3'!"0`````Z.;L__^+`(D$).C,Z?__B00DZ*3L__^+`(E#,(UD)!1;7<.0
MC;0F`````%6)Y5>)QU93C:0D9/___X7`=`6`.`!U$(VD))P```!;7E]=PXUT
M)@")!"3H$.K__X7`B<9TXF:0B30DZ'#J__^%P`^$T````(U8$P^V%<;)!`@/
MMD`3.=`/A-H````/MA7%R00(.=`/A.,```")/"3H:^K__XD<)(E%@.A@ZO__
MBU6`C40"`HD$).CQZO__B46$B5PD%(E\)!#'1"0,R,D$",=$)`C_____QT0D
M!`$```")!"3HENO__XU%B(E$)`B+183'!"0#````B40D!.@<Z/__@_C_=!.+
M19@E`/```#T`0```#X2,````BT6$B00DZ/GI__^+182)!"3H[NC__XDT).BF
MZ?__A<`/A3;___^-M@````")-"3H(.K__XD\).B(ZO__C:0DG````%M>7UW#
MC70F``^V4P$Z%<?)!`@/A/#^___I$?___XUV``^V0P$Z!<;)!`@/A0W___\/
MMD,".@7'R00(#X3(_O__Z?C^__^-=@"+183H@/[__^ER____C70F`(V\)P``
M``!5B>53B<.-9"3LQP0D`````.@:Z___BP")!"3H`.C__XD$).@HZO__B40D
M"(E<)`3'!"0#````Z$3H__^%P'00C60D%#'`6UW#C;0F`````,<$)`````#H
MU.K__XL`B00DZ+KG__^)!"3HXNG__XM`$"4`\```/0!```!T+<<$)`````#H
MI^K__XL`B00DZ(WG__^)!"3HM>G__XM`$"4`\```/0"@``!UEHD<),=$)`0"
M````Z-;G__^%P`^4P(UD)!0/ML!;7<.-M"8`````58GEC:0DN-___V6A%```
M`(E%Y#'`B5WTB77XB7W\C9WC[___Z-?E__^)1"00QT0D%,')!`C'1"0,SLD$
M",=$)`@!$```QT0D!`$```")'"3HF^G__X7`>1\QVXM5Y&4S%10```")V'56
MBUWTBW7XBWW\B>Q=PV:0QT0D"``0``"-O>+?__^)'"2)?"0$Z/[H__^%P(G&
M>,&-0`&)!"3H?>C__X7`B<-TLHET)`B)?"0$B00DZ*?G___&!#,`ZYSH?.C_
M_XVV`````(V_`````%6)Y8UD)/C)Z2/___^-=@!5B>575HG&,<!3B=.-9"3$
M@#H]#Y3``<.)'"3H@.?__XG'C57DB?#HA/?__X7`=#B)!"2)1=#H9>?__S')
M.<>+5=`/AX@!```/M@0+A,"(!`J-20%U\HUD)#PQP%M>7UW#C;0F`````*%`
M/@4(,=*Y"````(,X`'08C;0F`````(U2`8L,D(7)=?:-#)4(````@SU@/@4(
M`'0VB4PD!(E5T(D$).CGY/__A<")P:-`/@4(BU70#X4C`0``C60D/+C_____
M6UY?7<.-M"8`````B0PDB570QP5@/@4(`0```.A;Y___A<")P8M5T'3-C025
M`````(E%U(E$)`BA0#X%"(D,)(E-S(E$)`3HL.?__XM-S(M5T(D-0#X%",=$
MD00`````B57D#[86@/H]#X29````A-*)\`^$CP```(UV`(U``0^V$(#Z/70$
MA-)U\2GPBU74`Q5`/@4(C40X`HE5T(D$).C7YO__BU70A<")`@^$1?___XM5
MY*%`/@4(BP20#[86A-*($'0B@/H]=!V-=@'K"8UT)@"`^CUT#P^V%HU``832
MB!"-=@%U[,8`/3'2C;0F``````^V#!.$R8A,$`&-4@%U\>F*_O__,<#K@8M%
MY,'@`HE%U.E)____C025`````(E%U.DO____C78`58GE5[_DR00(5HUUV%.[
MVLD$"(UD))3'1=#DR00(QT74VLD$",=%V.?)!`C'1=S=R00(QT7@XLD$",=%
MY"7+!`CK*9"-="8`BT4(B10DB40D!(E5O.CFY?__A<!T.H`[`'0JBP:)WXUV
M!(G#B?CH_?7__X7`B<)T!8`X`'7*BU4(B?CHB/W__X`[`'76C60D;%M>7UW#
M9I"+30B)#"3H#>7__XE%Q*&4RP0(B00DZ/WD__^+5;R)1<")%"3H[^3__XE%
MM(M-P(M%Q(U,"`*+1;0!R(D$).AUY?__B<&AE,L$"(M5O(E$)!2+10B)5"08
MB0PDB4V\B40D$,=$)`S>R@0(QT0D"/_____'1"0$`0```.@)YO__BTV\B?B)
MRNCM_/__Z3;___^0C;0F`````%6)Y5=6C60DT&6A%````(E%]#'`H6S+!`B)
M1=*A<,L$"(E%UJ%TRP0(B47:H7C+!`B)1=ZA?,L$"(E%XJ&`RP0(B47FH83+
M!`B)1>JAB,L$"(E%[@^W!8S+!`AFB47RN/3)!`CH1_7__[@$R@0(Z#WU__^X
M$,H$".@S]?__N*S)!`CH*?7__[@9R@0(Z!_U__^X(\H$".@5]?__N"W*!`CH
M"_7__[@ZR@0(Z`'U__^X0\H$".CW]/__N$[*!`CH??3__X7`=`R)PK@9R@0(
MZ`W\__^X7\H$".AC]/__A<!T#(G"N''*!`CH\_O__[A\R@0(Z$GT__^%P'0U
MB<*X$,H$".C9^___NJC*!`BX],D$".C*^___BT7T93,%%````'5.C60D,%Y?
M7<.-M@````"XC,H$".@&]/__A<!T$HG"N*S)!`CHEOO__^N[C70F`(UUX[^=
MR@0(N0H```#SIG6FC57MN*S)!`CH<OO__^N7Z,OC__^-="8`C;PG`````%6)
MY8UD).CH-./__XD$).@,X___B<(QP(72=`*+`LG#58GE5E.-9"3PBUT(A=MT
M8(`[`'1;B1PDZ,/B__^-1`/_.<,/@]P```"+-9#+!`@/M@@/MA8XT70+ZUF0
MC70F`#@(=5"-0/\YPW+U.=AU40^V`#H&#X2.````B74(C60D$%M>7>F7Y/__
MC;0F`````,<$)`(```#H!./__X7`=`5FQP`N`(UD)!!;7EW#C78`.!!TMXU`
M_SG#<O4YV'2PD(U`_SG#<P</MA`Z%G3RB<(QP"G:C4H"@?D`$```=\:-4@''
M1"0,`!```(E4)`B)7"0$QP0D@#X%".BRW___N(`^!0CKH(UV`,<$)`(```#H
MC.+__XG",<"%TG2)9L<"+@")T.N`BS60RP0(Z3O___]5B>575E.-9"3DBW4(
MB30DZ-O^__\/M@B)QX3)B<-T'Z&0RP0(C5<!#[8`D(UT)@`XP0^V"@]$VH3)
MC5(!=?'H;/+__X7`=!Z%]G0:@#X`D'04QT0D!*K*!`B)'"3H_N'__SG8=`F-
M9"0<6UY?7<.-9"0<B?!;7E]=Z7+V__]FD%6)Y8/D\%93C440C60DR(E$)`B-
M10R)1"0$C44(B00DZ/OB___'1"0(,)4$",=$)`0PE00(QP0D`)<$".@_$@``
MQP0D`````.@#X/__@#@`=3OHZ=___X7`HX!.!0@/A+`!``")!"3HI.#__\<$
M)`````#HN.+__XL`B00DZ)[?__^)!"3H!N+__\8``,<$)`````#HE^+__XL`
MB00DZ'W?__^)!"3HE>+__X`(`L<$)`````#H=N+__XL`B00DZ%S?__^)!"3H
M=.+__X`(`8M%"(/`!3')B40D*(E,)"S?;"0HV`48S`0(W04@S`0(V<G?Z=W8
M#X<%`0``P>`"B00DZ)KA__^+=0RCC$X%"(L6QT`$K\H$"(D0QT`(0,P$",=`
M#++*!`B+70B#^P''!8A.!0@$````?A6Z`0```&:0BPR6B4R0#(U2`3G3?_*-
M6P/'!)@`````B40D#*&`3@4(B5PD",=$)!``````QT0D!"#(!`B)!"3HD]W_
M_X7`B<-T/:&`3@4(B00DZ$#@__^X!,H$".AV\/__A<!T.J&`3@4(B00DZ$7=
M___H$-___XUD)#B)V%M>B>Q=PXUT)@"A@$X%"(D$).CCW?__B</KLHVT)@``
M``"AA$X%"(7`=`J)!"3HE_W__^NSN!#*!`CH&_#__X7`HX1.!0ATH.OAQT0D
M!$0^!0C'!"37R00(Z&S@___'!"0!````Z&#A__]5B>575E.-I"2T[___BT4(
MB874[___N!#*!`AEBQ44````B57D,=*+=0SHP>___XG'BQV0RP0(BX74[___
MB5PD!(D$).AWW___A<!T,HN5U.___[@MR@0(Z#/W__^+5>1E,Q44````BX74
M[___#X6P`0``C:0D3!```%M>7UW#BY74[___B10DZ*/>__^)A=#O__^AE,L$
M"(DT)(E$)`3H;-___X7`B<9THXN5T.___X/"`8F5T.___XVT)@````"`/@"X
MQLD$"`]$\(7_=!2)="0$B3PDZ%7@__^%P`^$V0```(DT).A%WO__#[94!O\Z
M$W46C10&D,9"_P"-0/\/MDK^.@N-4O]T[@.%T.___SW_#P``#X\R____BY74
M[___C87D[___B50D&(E<)!2)="00QT0D#-[*!`C'1"0(`!```,=$)`0!````
MB00DZ$W?___'!"0`````Z+'?__^+`(D$).B7W/__B00DZ+_>__^)1"0(C97D
M[___QP0D`P```(E4)`3HM=O__X7`=2W'!"0`````Z'7?__^+`(D$).A;W/__
MB00DZ(/>__^+0!`E`/```#T`@```="2AE,L$",<$)`````")1"0$Z#_>__^%
MP(G&#X7E_O__Z6W^__^-A>3O___'1"0$`0```(D$).AZW/__A<!UPHV5Y.__
M_[@MR@0(Z(;U__^-E>3O__^)%"3H.-___XF%U.___^DZ_O__Z,C=__^0C;0F
M`````%6)Y5=64XVD),1^__^+10B)A01___^X$,H$"&6+%10```")5>0QTL>%
M*'___[7*!`C'A2Q___^]R@0(QX4P?___QLD$",>%-'___R7+!`C'A1!___]Q
MR@0(QX44?___:LH$",>%&'___\+*!`C'A1Q___^XR@0(QX4@?___RLH$",>%
M)'___R7+!`C'A3A____.R@0(QX4\?___T\H$",>%0'___R7+!`CH$NW__X7`
M=`F`.``/A8T"``"0C70F`.@[^?__A<")QP^$H0(```^V'X3;="+HI=O__XGZ
MC78`BP@/OMOV!%D(=0/&`E^-4@$/MAJ$VW7HC9T4?___N''*!`CK$8UV`(L#
MC5L$@#@`#X3R`0``Z*7L__^%P(G&=.?HBO+__X7`=-Z)-"3H[MW__X7`=-*)
MQHDT).C`V___B<.)/"3HMMO__XV$`P0$``")!"3H1]S__XG#B7PD'(L]D,L$
M"(F%`'___\=$)!BJR@0(B7PD%(ET)!#'1"0,W,H$",=$)`C_____QT0D!`$`
M``")!"3HU=S__\=$)`3M`0``B1PDZ.78__^XW<D$".@+[/__A<`/A/,!``")
M!"3H6]W__XN5!'___XE$)`2+`HD$).CW^___A<")Q@^$S0$``.CXZ___A<!U
M'L=$)`0`````B30DZ*3<__^%P(F%!'___P^%M@$``(D<)#'_Z.S:__^)QKJH
MR@0(N*S)!`CH._/__^A6V/__B40D&*&0RP0(QT0D'"7+!`B)1"04B5PD$,=$
M)`SYR@0(QT0D"/_____'1"0$`0```(D<).@-W/__ZU>-=@#H\]?__X,X$75?
MQ@0S`(U_`>@"V/__BQ60RP0(QT0D("7+!`B)?"0<B40D&(E4)!2)7"00QT0D
M#`?+!`C'1"0(_____\=$)`0!````B1PDZ+3;___'1"0$[0$``(D<).C$U___
M@_C_=)>)VK@0R@0(Z(/R__^)'"3H:_3__XM]Y&4S/10```"+A0!___\/A>(%
M``"-I"0\@0``6UY?7<.0C;4L?___N[7*!`CK#8UV`(L>C78$@#L`=!N)V.B'
M\/__,=*%P'3IB1PDZ.G;__^%P(G"=-N)UNGT_?__C70F`(D$)(F%^'[__^CZ
M\___BX7X?O__B00DZ+S;__^)A0!____I=O___Y"-G3Q___^XSLH$")"-="8`
MZ#OJ__^%P'00B00DZ(_;__^%P`^%/04``(L#C5L$@#@`==V_&,L$".E+_?__
MC78`B[T$?___BS?I)O[__XUV`,=$)`P"````QT0D!.[____'1"0(_____XD$
M).APU___BY4$?___C85$?___QT0D"`8```")1"0$B10DZ.#7__^`O41___\`
M=0V`O45___]##X3G`P``C85@____QX5$____`2-%9\>%2/___XFKS>_'A4S_
M___^W+J8QX50____=E0R$,>%5/____#ATL/'A5C___\`````QX5<____````
M`,=%H`````")A?1^__^)G?Q^__^-=@"+A01____'1"0(`(```(V]1'___XD$
M)(E\)`3H2-?__X7`B<,/CGX!``"+C5C___^+A5S___^-O41___^-%-F)E5C_
M__\YRH/0`(F%7/___XG8P>@=`85<____BT6@A<!T5K]`````C95@____*<<Y
M^P].^P'0B7PD"(V51'___XD$)(E4)`3HW-?__XM%H`'X@_A`B46@#X5C____
MC85$?___*?L!QXV%1/___^@VV___C;8`````@_L_#XZ\````,?:0C70F`(L$
M-XF%8/___XM$-P2)A63___^+1#<(B85H____BT0W#(F%;/___XM$-Q")A7#_
M__^+1#<4B85T____BT0W&(F%>/___XM$-QR)A7S___^+1#<@B46`BT0W)(E%
MA(M$-RB)18B+1#<LB46,BT0W,(E%D(M$-S2)192+1#<XB468BT0W/(E%G(V%
M1/___^B.VO__B=B-=D`I\(/X/P^/7O___XU;P(G8P>@&B<+!X@8ITXU\.D"-
ME6#____'1"0,1````(E<)`B)?"0$B10DZ*W5__^)7:#I7?[__Y"-="8`BY4$
M?___BYW\?O__B10DZ#S7__^+M5C___^+E5S___^)\,'H`X/@/\:$!6#___^`
M@\`!@_@X#X\L`@``N3@```"-O6#___\IP0'XB97X?O__B4PD",=$)`0`````
MB00DZ`O5__^+E?A^__^)T(A5F\'H&(U]IXA%F(G0P>@0B$69B=#!Z`B(19J)
M\,'H&(A%G(GPP>@0B$6=B?#!Z`B(19Z)\(A%GXV%1/___^B/V?__BY5$____
M,?:)T8A5T\'I&(G(B$W0B='!Z1"(3=&)T<'I"(N52/___XA-THG1P>D8B%77
MB$W4B='!Z1"(3=6)T<'I"(N53/___XA-UHG1P>D8B%7;B$W8B='!Z1"(3=F)
MT<'I"(N54/___XA-VHG1P>D8B%7?B$W<B='!Z1"(3=V)T<'I"(N55/___XA-
MWHG1P>D8B%7CB$W@B='!Z1"(3>&)T<'I"(A-XNL)C70F``^V1#70#[;`C78!
MB3PDB40D$,=$)`STR@0(QT0D"/_____'1"0$`0```(U_`NB^UO__@_X4=<G&
M1<\`QT0D'"7+!`B-5:>+/9#+!`B)5"08B7PD%(E<)!#'1"0,Y<H$",=$)`C_
M____QT0D!`$```")'"3H>-;__^G4^O__@+U&?___00^%#/S__X"]1W___T,/
MA?_[__^`O4A___](#X7R^___@+U)?___10^%Y?O__XN]!'___\=$)`P"````
MQT0D!,;____'1"0(_____XD\).CYTO__C85$?___QT0D""D```")1"0$B3PD
MZ&_3___'1"0<)<L$"(V51'___^E"____C70F`+E`````C;U@____*<$!^(E,
M)`B)E?A^___'1"0$`````(D$).C?TO__C85$____Z*37__^Y#@```#'`B[WT
M?O__\ZN+E?A^___IM?W__XG'Z?+W___HWM3__XVT)@````"-O"<`````58GE
M5U93C60DU,<$)`````#HVM7__XL`B00DZ,#2__^)!"3H.-/__\8``;CTR00(
MZ)OD__^%P'0)@#@Q#X0.`P``Z$GO___'!"0`````Z)W5__^+`(D$).B#TO__
MB00DQT0D#`L```#'1"0(`0```,=$)`0?RP0(Z!/2__^%P`^$VP```(M`##'V
MNP$```"+0!B)1>2AB$X%"(/X`7\XZ;$```"-="8`BT<,BQ6,3@4(BQ2:B40D
M!(D4).A0U?__A<`/A8@```"-6P&AB$X%"#G8C78!?G['!"0`````Z`W5__^+
M`(D$).CST?__BU7DQT0D#`````")="0(B50D!(D$).A8T___A<!T1(LX]D<)
M!'64QP0D`````.C0U/__BP")!"3HMM'__XD$),=$)`P"````QT0D"`````")
M?"0$Z!K5___I8/___Y"-="8`H8A.!0B-4/\Y\@^$@`$``,<$)`````#HA-3_
M_XL`B00DZ&K1__^)!"3'1"0,!0```,=$)`@!````QT0D!"3+!`CH^M#__X7`
MB<-T/HM`#(LPQP0D`````.A#U/__BP")!"3H*='__XD$),=$)`@FRP0(B70D
M!.CET/__BT,,BQCV0PI`#X5.`0``QP0D`````.@*U/__BP")!"3H\-#__XD$
M),=$)`P%````QT0D"`$```#'1"0$3,H$".B`T/__A<")PW0_N"W*!`CHL.+_
M_X7`B<8/A#X!``"+0PR+.,<$)`````#HM=/__XL`B00DZ)O0__^)!"2)="0(
MB7PD!.A;T/__QP0D`````.B/T___BP")!"3H==#__XD$).CMT/__Q@``QP0D
M`````.ANT___BP")!"3H5-#__XD$).B,T___QP``````N!#*!`CH+.+__X7`
MHX1.!0@/A.<```#'1"0$[0$``(D$).C?SO__@_@1=!"%P'0,@_C_C78`#X4G
M`0``C60D+%M>7UW#D(/X`0^.=_[__[L!````9I#'!"0`````C5L!Z/'2__^+
M`(D$).C7S___BU7DB00DB50D!.AHS___.1V(3@4(?]#I._[__XUV`,<$)```
M``#HO-+__XL`B00DZ*+/__^)!"2)7"0$Z';1___IB_[__Y"`>`$`#X3M_/__
MC;8`````Z=W\__^-=@"AC$X%"(LXBT,,BS#'!"0`````Z'#2__^+`(D$).A6
MS___B?F)\NCMX?__Z;W^__^AC$X%"(D$).AK\___HX1.!0B+0PR+/8Q.!0B+
M,/9&"00/A)8```"+1@R)?"0$B00DZ#+0__^)QHM##(L8]D,)!'1&BT,,B40D
M"*&,3@4(B70D#(L`QP0DF,L$"(E$)`3H0]'__XE$)`RAA$X%"(E$)`BAC$X%
M"(L`QP0DR,L$"(E$)`3H']'__\<$)`````#HP]'__XL`B00DZ*G.__^)!"3'
M1"0,`@```,=$)`@`````B5PD!.@-TO__ZXG'!"0`````Z(_1__^+`(D$).AU
MSO__B00DQT0D#`(```#'1"0(`````(ET)`3HV='__^DV____C70F`%6)Y8UD
M).C'!"0`````Z$W1__^+`(D$).@SSO__B00DQT0D#"O+!`C'1"0(\)8$",=$
M)`0URP0(Z`/1___)PY!5B>6-9"38QP0D`````.@-T?__BP")!"3H\\W__XD$
M).B;____QP0D`````.COT/__BP")!"3HU<W__XD$),=$)!0`````QT0D$"7+
M!`C'1"0,)<L$",=$)`A0PP0(QT0D!%'+!`CHA<[__\G#D)"058GE4^@R````
M@<,S=```@^P0BX/<C/__B40D#(M%$(E$)`B+10R)1"0$BT4(B00DZ-O,__^#
MQ!!;7<.+'"3#D%6)Y5W#C70F`(V\)P````!5B>575E/HX/___X'#X7,``(/L
M'.B'R___C;O8_O__C8/8_O__*<?!_P*%_W0D,?:+11")1"0(BT4,B40D!(M%
M"(D$)/^4L]C^__^#Q@$Y_G+>@\0<6UY?7<.0D)"0D)!5B>53C60D_*&D.P4(
M@_C_=!*[I#L%")"-6_S_T(L#@_C_=?2-9"0$6UW#D%6)Y5.#[`3H`````%N!
MPU1S``#H;-#__UE;R<,````````````````````````````````#`````0`"
M``````!005)?0TQ%04X`+W!R;V,O<V5L9B]E>&4`+BX`)7,O)7,`+W!R;V,O
M)6DO)7,`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27U1%35``4$%27T1%0E5'`%!!4E]#04-(10!0
M05)?4%)/1TY!344`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`'!A<BT`+64`+2T`
M0SI<5$5-4``O=&UP`%1%35!$25(`5$U0`%5315(`55-%4DY!344`)7,E<R5S
M)7,`)7,E<V-A8VAE+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`4UE35$5-`$%21U8`&`!P97)L`'!E<FQX<VDN8P!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+P`Z
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````9LL$"&C+
M!`@E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@``````````
M``````"`____ST%P87(N<&P````````````````````````C(2]U<W(O8FEN
M+W!E<FP*"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N
M;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@
M<W1R:6-T.PH*(VQI;F4@,34Y"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O
M;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@
M=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R
M="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T
M:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC
M86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN
M:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L
M97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*
M("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L
M;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T
M(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R
M;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H
M:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@
M("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@
M("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@
M("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.
M2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I
M;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@
M)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@
M("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*
M("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE
M;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@
M("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM0
M05)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6
M(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%2
M1T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92![
M"B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1?
M?2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M
M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG
M(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@
M(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N
M('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@
M("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M
M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@
M)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N
M<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@
M("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@
M(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M
M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA
M;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F
M=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@
M(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@
M("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@
M/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T
M*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@
M)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@
M("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@
M("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X
M="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@
M("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@
M<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES
M='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@
M)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@
M("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@
M("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]
M?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@
M;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L
M:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE
M7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y
M?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@
M("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB
M=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@
M(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL
M96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN
M="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H
M+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@
M("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B
M=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J
M96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@
M:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I
M;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@
M("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I
M;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K
M:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@
M("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@
M?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]
M?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["@HC($1O;B=T('-W86QL
M;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T
M("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C
M;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@
M:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@
M(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*
M("`@(&UY($!A9&1?=&]?:6YC.PH@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@
M("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*"B`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("!P
M=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@
M('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@
M)&)U;F1L92`]("=S:71E)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@
M)'%U:65T(#T@,3L*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=,
M)RD@>PH@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("1C86-H95]N86UE
M(#T@)#(["B`@("`@("`@?0H*("`@("`@("!S:&EF="A`05)'5BD["@H@("`@
M("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@:6YI=%]I
M;F,H*3L*("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@
M("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@
M("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*"B`@("!U;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B
M=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI
M;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@
M("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@
M("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*
M("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@
M("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A
M(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@
M:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0[
M"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A0
M05(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50
M871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@
M("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N
M9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@
M("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@
M;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@
M("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD[
M"B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L
M960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U
M:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@
M("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G
M<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*
M("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@
M("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@
M("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M("`@("`@("!]($!)3D,["@H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI;7T@
M97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0H*("`@("`@("`C($9I
M;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@
M("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#
M;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES
M(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H
M92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H
M('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*
M("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I
M;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@
M=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@
M("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY
M("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B
M(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N
M+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*
M("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@
M("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@
M("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R
M('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T
M;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q
M(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@
M("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C
M;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W
M('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R
M(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4[
M"B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]
M"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C
M:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2
M(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R
M97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&
M:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@
M("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@
M("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY
M("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@
M("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC
M92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@
M("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP
M;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]
M"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*
M("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I
M<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@
M("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@
M("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@
M<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U
M:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER
M92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I
M<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R
M97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(&5V86P@>R!R97%U
M:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PI]"@HC(%1H92!#('9E<G-I
M;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC
M(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E
M=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U
M<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I
M('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@
M("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW
M:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@
M("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD
M=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@
M,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@
M("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@
M("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O
M9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$[
M"B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@
M;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E
M;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F
M:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C
M<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@
M=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@
M("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N
M86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@
M("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]
M"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R
M;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R
M;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K
M92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*
M("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P
M87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@
M("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N
M)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2![
M"B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@
M("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V
M86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S
M('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@
M("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*
M("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@
M("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O
M<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ
M.PH*(VQI;F4@,3`P,@H*7U]%3D1?7PH````!&P,[Z````!P```#0=/__!`$`
M`!!U__\L`0``P('__UP!``!P@O__C`$``)""__^L`0``X(+__]@!```@@___
M``(``""$__\P`@``@(3__U`"``#0AO__>`(``&"(__^X`@``,(G__^@"````
MBO__&`,``!"*__\X`P```(S__W@#```PC?__K`,``+".___8`P``T([___@#
M``#@C___,`0``&"0__]L!```@)+__ZP$``"PE/__W`0``*"=__\0!0``,*+_
M_T`%``!PHO__8`4``."B__^`!0``(*/__Z0%```PH___Q`4``!0`````````
M`7I2``%\"`$;#`0$B`$``"0````<````Q'/__S,`````00X(0H4"#05%@P2&
M`VC#0<9!Q0P$!``L````1````-QS__^K#````$$."$2%`@T%0X<#2H8$58,%
M`X`,PT'&0<=!Q0P$!``L````=````%R`__^L`````$$."$*%`@T%48<#A@2#
M!5(*#03'QL-!Q0X$00L````<````I````-R`__\1`````$$."$*%`@T%3<4,
M!`0``"@```#$````W(#__T0`````00X(0H4"#05/"L4,!`1&"V,*#`0$Q44+
M````)````/``````@?__/0````!!#@A"A0(-!4.&`T2#!'##0<9!Q0P$!"P`
M```8`0``&('___,`````00X(0H4"#05LAP.&!(,%`H$*#03'QL-!Q0X$1PL`
M`!P```!(`0``Z('__UT`````00X(0H4"#04"6<4,!`0`)````&@!```H@O__
M2`(```!!#@A"A0(-!4R#`P,W`L-!Q0P$!````#P```"0`0``4(3__X4!````
M00X(0H4"#05#AP--@P6&!$T*PT'&0<=!Q0P$!$4+`P@!"L-!QD''00P$!,5%
M"P`L````T`$``*"%___)`````$$."$*%`@T%0X,#`D$*PT'%#`0$2`L"=\-!
M#`0$Q0`L``````(``$"&___$`````$$."$*%`@T%88<#A@2#!0)0"@T$Q\;#
M0<4.!$,+```<````,`(``."&__\-`````$$."$*%`@T%1<4,!`0``#P```!0
M`@``T(;__^T!````00X(0H4"#05$A@2'`T6#!0)1"L-!QD''0<4,!`1("P)=
M"L-!QD''00P$!,5("P`P````D`(``("(__\H`0```$$."$*%`@T%1H<#1(8$
M1H,%`G\*PT'&0<=!Q0P$!$,+````*````,0"``!\B?__=0$```!!#@A"A0(-
M!0)AA@2'`P+#"L9!QT'%#`0$1PL<````\`(``-"*__\@`````$$."$*%`@T%
M7,4,!`0``#0````0`P``T(K__Q`!````00X(0H4"#05)@P2&`P)6"L-!QD'%
M#`0$3`M:"L-!QD'%#`0$1`L`.````$@#``"HB___?@````!!#@A"A0(-!4J#
M!88$AP,"7@K#0<9!QT'%#`0$00M'PT'&0<=!Q0P$!```/````(0#``#LB___
M(`(```!!#@A"A0(-!5T0`PAU``GP&@GX(A`&"'4`"?`:"?PB`Y<!"L-!QD(-
M!$'%#@1%"RP```#$`P``S(W__R@"````00X(0H4"#05G@P6&!(<#`E$*PT'&
M0<=!Q0P$!$$+`#````#T`P``S(___^((````00X(0H4"#04"IH,%A@2'`P-:
M`@K#0<9!QT'%#`0$0@L````L````*`0``(B8__^,!````$$."$*%`@T%3H,%
MA@2'`P/*`@K#0<9!QT'%#`0$0@L<````6`0``.B<__\_`````$$."$*%`@T%
M>\4,!`0``!P```!X!```")W__VT`````00X(0H4"#04":<4,!`0`(````)@$
M``!8G?__.P````!!#@A"A0(-!4R#`VK#0<4,!`0`'````+P$``!TG?__!0``
M``!!#@A"A0(-!4'%#`0$```H````W`0``&2=__]:`````$$."$*%`@T%3H,%
MA@2'`P)%PT'&0<=!Q0P$!`````#_____`````/____\```````````$````!
M`````0```*T"```!````O`(```$```#(`@```0```-,"```!````W0(```$`
M``#K`@```0```/@"```!````1P,```\```"M!```#````("4!`@-````;,D$
M"/7^_V^,@00(!0```"2*!`@&````Y(($"`H````[!@``"P```!`````5````
M``````,```#,/`4(`@```(`"```4````$0```!<`````D@0($0```.B1!`@2
M````&````!,````(````_O__;TB1!`C___]O`@```/#__V]@D`0(````````
M````````````````````````````````````````````````````````````
M`+@[!0@``````````,:4!`C6E`0(YI0$"/:4!`@&E00(%I4$"":5!`@VE00(
M1I4$"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&E00(UI4$".:5!`CV
ME00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6!`B&E@0(EI8$"*:6
M!`BVE@0(QI8$"-:6!`CFE@0(]I8$"`:7!`@6EP0()I<$"#:7!`A&EP0(5I<$
M"&:7!`AVEP0(AI<$"):7!`BFEP0(MI<$",:7!`C6EP0(YI<$"/:7!`@&F`0(
M%I@$"":8!`@VF`0(1I@$"%:8!`AFF`0(=I@$"(:8!`B6F`0(II@$"+:8!`C&
MF`0(UI@$".:8!`CVF`0(!ID$"!:9!`@FF00(-ID$"$:9!`A6F00(9ID$"':9
M!`B&F00(EID$"*:9!`BVF00(`````/____\HS`0(;5D``$=#0SH@*$=.52D@
M-"XT+C(@,C`P.3$P,C<@*%)E9"!(870@-"XT+C(M-RD``$=#0SH@*$=.52D@
M-"XT+C(@,C`P.3$P,C<@*%)E9"!(870@-"XT+C(M-RD``$=#0SH@*$=.52D@
M-"XT+C(@,C`P.3$P,C<@*%)E9"!(870@-"XT+C(M-RD``"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R
M`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```
M```````````````````````````````````````````````````````+````
M`0````(````T@00(-`$``!,```````````````$`````````$P````<````"
M````2($$"$@!```@```````````````$`````````"$````'`````@```&B!
M!`AH`0``)```````````````!``````````T````]O__;P(```",@00(C`$`
M`%@!```%``````````0````$````/@````L````"````Y(($".0"``!`!P``
M!@````$````$````$````$8````#`````@```"2*!`@D"@``.P8`````````
M`````0````````!.````____;P(```!@D`0(8!```.@````%``````````(`
M```"````6P```/[__V\"````2)$$"$@1``"@````!@````(````$````````
M`&H````)`````@```.B1!`CH$0``&`````4`````````!`````@```!S````
M"0````(`````D@0(`!(``(`"```%````#`````0````(````?`````$````&
M````@)0$"(`4```P```````````````$`````````'<````!````!@```+"4
M!`BP%```$`4`````````````!`````0```""`````0````8```#`F00(P!D`
M`*PO`````````````!``````````B`````$````&````;,D$"&Q)```<````
M```````````$`````````(X````!`````@```*#)!`B@20``#EP`````````
M````(`````````"6`````0````(```"P)04(L*4``.P```````````````0`
M````````I`````$````"````G"8%")RF```(!0`````````````$````````
M`*X````!`````P```*0[!0BDJP``"```````````````!`````````"U````
M`0````,```"L.P4(K*L```@```````````````0`````````O`````$````#
M````M#L%"+2K```$```````````````$`````````,$````&`````P```+@[
M!0BXJP``$`$```8`````````!`````@```#*`````0````,```#(/`4(R*P`
M``0```````````````0````$````SP````$````#````S#P%",RL``!,`0``
M```````````$````!````-@````!`````P```!@^!0@8K@``$```````````
M````!`````````#>````"`````,```!`/@4(**X``%`0`````````````"``
M````````XP````$``````````````"BN``"&```````````````!````````
I``$````#``````````````"NK@``[````````````````0``````````
